@@ -4,6 +4,9 @@ function Fileslisting(parent) {
     self.parent = parent;
     self.fileItems = ko.observableArray([]);
 
+    // Prevent flash of unstyled content when deleting items
+    self.fileItems.extend({ rateLimit: 50 })
+
     // Need to reserve these names to be overwritten
     self.filelist_name = ko.observable();
     self.filelist_password = ko.observable();
@@ -30,42 +33,17 @@ function Fileslisting(parent) {
         $('#modal-item-files').modal('show');
 
         // Stop updating on closing of the modal
-        $('#modal-item-files').on('hidden.bs.modal', function() {
+        $('#modal-item-files').on('hidden.bs.modal', function () {
             self.removeUpdate();
         })
     }
 
-    // Move to top and bottom buttons
-    self.moveButton = function (item,event) {
-        var targetRow, sourceRow, tbody;
-        sourceRow = $(event.currentTarget).parents("tr").filter(":first");
-        tbody = sourceRow.parents("tbody").filter(":first");
-        ko.utils.domData.set(sourceRow[0], "ko_sourceIndex", ko.utils.arrayIndexOf(sourceRow.parent().children(), sourceRow[0]));
-        sourceRow = sourceRow.detach();
-        if ($(event.currentTarget).is(".buttonMoveToTop")) {
-            // we are moving to the top
-            targetRow = tbody.children(".files-done").filter(":last");
-        } else {
-            //we are moving to the bottom
-            targetRow = tbody.children(".files-sortable").filter(":last");
-        }
-        if(targetRow.length < 1 ){
-        // we found an edge case and need to do something special
-            targetRow = tbody.children(".files-sortable").filter(":first");
-            sourceRow.insertBefore(targetRow[0]);
-        } else {
-            sourceRow.insertAfter($(targetRow[0]));
-        }
-        tbody.sortable('option', 'update').call(tbody[0],null, { item: sourceRow });
-    };
-
     // Trigger update
     self.triggerUpdate = function() {
         // Call API
         callAPI({
             mode: 'get_files',
-            value: self.currentItem.id,
-            limit: 5
+            value: self.currentItem.id
         }).then(function(response) {
             // When there's no files left we close the modal and the update will be stopped
             // For example when the job has finished downloading
@@ -79,7 +57,7 @@ function Fileslisting(parent) {
             $.each(response.files, function(index, slot) {
                 // Existing or updating?
                 var existingItem = ko.utils.arrayFirst(self.fileItems(), function(i) {
-                    return i.nzf_id() == slot.nzf_id;
+                    return i.nzf_id() === slot.nzf_id;
                 });
 
                 if(existingItem) {
@@ -98,7 +76,7 @@ function Fileslisting(parent) {
             }
 
             // Check if we show/hide completed
-            if(localStorageGetItem('showCompletedFiles') == 'No') {
+            if(localStorageGetItem('showCompletedFiles') === 'No') {
                 $('.item-files-table tr.files-done').hide();
                 $('#filelist-showcompleted').removeClass('hover-button')
             }
@@ -124,36 +102,57 @@ function Fileslisting(parent) {
     self.move = function(event) {
         // How much did we move?
         var nrMoves = event.sourceIndex - event.targetIndex;
-        var direction = (nrMoves > 0 ? 'Up' : 'Down')
+        var direction = (nrMoves > 0 ? 'up' : 'down')
 
-        // We have to create the data-structure before, to be able to use the name as a key
-        var dataToSend = {};
-        dataToSend[event.item.nzf_id()] = 'on';
-        dataToSend['apikey'] = apiKey;
-        dataToSend['action_key'] = direction;
-        dataToSend['action_size'] = Math.abs(nrMoves);
+        callAPI({
+            mode: 'move_nzf_bulk',
+            name: direction,
+            value: self.currentItem.id,
+            nzf_ids: event.item.nzf_id(),
+            size: Math.abs(nrMoves)
+        }).then(function() {
+            // Refresh all the files
+            self.loadFiles(self.currentItem)
+        })
+    };
 
-        // Activate with this weird URL "API"
-        callSpecialAPI("./nzb/" + self.currentItem.id + "/bulk_operation/", dataToSend)
+    // Move to top and bottom buttons
+    self.moveButton = function (item, event) {
+        // Up or down?
+        var direction = "bottom"
+        if ($(event.currentTarget).is(".buttonMoveToTop")) {
+            // we are moving to the top
+            direction = "top"
+        }
+
+        callAPI({
+            mode: 'move_nzf_bulk',
+            name: direction,
+            value: self.currentItem.id,
+            nzf_ids: item.nzf_id()
+        }).then(function() {
+            // Refresh all the files
+            self.loadFiles(self.currentItem)
+        })
     };
 
     // Remove selected files
     self.removeSelectedFiles = function() {
-        // We have to create the data-structure before, to be able to use the name as a key
-        var dataToSend = {};
-        dataToSend['apikey'] = apiKey;
-        dataToSend['action_key'] = 'Delete';
-
         // Get all selected ones
+        var nzfIds = []
         $('.item-files-table input:checked:not(:disabled)').each(function() {
             // Add this item
-            dataToSend[$(this).prop('name')] = 'on';
+            nzfIds.push($(this).prop('name'))
         })
 
-        // Activate with this weird URL "API"
-        callSpecialAPI("./nzb/" + self.currentItem.id + "/bulk_operation/", dataToSend).then(function() {
-            // Set state of the check-all
-            setCheckAllState('#modal-item-files .multioperations-selector input[type="checkbox"]', '#modal-item-files .files-sortable input')
+        callAPI({
+            mode: 'queue',
+            name: 'delete_nzf',
+            value: self.currentItem.id,
+            value2: nzfIds.join()
+        }).then(function() {
+            // Refresh all the files
+            self.loadFiles(self.currentItem)
         })
     }
 
@@ -218,8 +217,8 @@ function FileslistingModel(parent, data) {
     self.nzf_id = ko.observable(data.nzf_id);
     self.file_age = ko.observable(data.age);
     self.mb = ko.observable(data.mb);
-    self.canselect = ko.observable(data.status != "finished" && data.status != "queued");
-    self.isdone =  ko.observable(data.status == "finished");
+    self.canselect = ko.observable(data.status !== "finished" && data.status !== "queued");
+    self.isdone =  ko.observable(data.status === "finished");
     self.percentage = ko.observable(self.isdone() ? fixPercentages(100) : fixPercentages((100 - (data.mbleft / data.mb * 100)).toFixed(0)));
 
     // Update internally
@@ -228,8 +227,8 @@ function FileslistingModel(parent, data) {
         self.nzf_id(data.nzf_id)
         self.file_age(data.age)
         self.mb(data.mb)
-        self.canselect(data.status != "finished" && data.status != "queued")
-        self.isdone(data.status == "finished")
+        self.canselect(data.status !== "finished" && data.status !== "queued")
+        self.isdone(data.status === "finished")
         // Data is given in MB, would always show 0% for small files even if completed
         self.percentage(self.isdone() ? fixPercentages(100) : fixPercentages((100 - (data.mbleft / data.mb * 100)).toFixed(0)))
     }
@@ -267,7 +266,7 @@ function paginationModel(parent) {
         // Return object for adding
         return {
             page: pageNr,
-            isCurrent: pageNr == self.currentPage(),
+            isCurrent: pageNr === self.currentPage(),
             isDots: false,
             onclick: function(data) {
                 self.moveToPage(data.page);
@@ -295,7 +294,7 @@ function paginationModel(parent) {
             self.nrPages(1)
             self.currentStart(0);
 
-            // Are we on next page?
+            // Are we on next page? Bad!
             if(self.currentPage() > 1) {
                 // Force full update
                 parent.parent.refresh(true);
@@ -303,9 +302,6 @@ function paginationModel(parent) {
 
             // Move to current page
             self.currentPage(1);
-
-            // Force full update
-            parent.parent.refresh(true);
         } else {
             // Calculate number of pages needed
             var newNrPages = Math.ceil(parent.totalItems() / parent.paginationLimit())
@@ -360,7 +356,7 @@ function paginationModel(parent) {
             }
 
             // Change of number of pages?
-            if(newNrPages != self.nrPages()) {
+            if(newNrPages !== self.nrPages()) {
                 // Update
                 self.nrPages(newNrPages);
             }
