@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -246,12 +246,12 @@ def _api_queue_priority(value: str, kwargs: Dict[str, Union[str, List[str]]]) ->
         try:
             try:
                 priority = int(priority)
-            except:
+            except Exception:
                 return report(_MSG_INT_VALUE)
             pos = sabnzbd.NzbQueue.set_priority(nzo_ids, priority)
             # Returns the position in the queue, -1 is incorrect job-id
             return report(keyword="position", data=pos)
-        except:
+        except Exception:
             return report(_MSG_NO_VALUE2)
     else:
         return report(_MSG_NO_VALUE2)
@@ -652,7 +652,7 @@ def _api_warnings(name: str, kwargs: Dict[str, Union[str, List[str]]]) -> bytes:
     return report(keyword="warnings", data=sabnzbd.GUIHANDLER.content())
 
 
-LOG_JSON_RE = re.compile(rb"'(apikey|api|username|password)': '(.*?)'", re.I)
+LOG_JSON_RE = re.compile(rb"'(apikey|api|username|password|email_(server|to|from|account|pwd))': '(.*?)'", re.I)
 LOG_INI_HIDE_RE = re.compile(
     rb"(apikey|api|user|username|password|email_pwd|email_account|email_to|email_from|pushover_token|pushover_userkey"
     rb"|apprise_(target_[a-z_]+|urls)|pushbullet_apikey|prowl_apikey|growl_password|growl_server|IPv[4|6] address|Public address IPv[4|6]-only|Local IPv6 address)\s?=.*",
@@ -667,8 +667,11 @@ def _api_showlog(name: str, kwargs: Dict[str, Union[str, List[str]]]) -> bytes:
     log_data += b"The log includes a copy of your sabnzbd.ini with\nall usernames, passwords and API-keys removed."
     log_data += b"\n\n--------------------------------\n"
 
-    with open(sabnzbd.LOGFILE, "rb") as f:
-        log_data += f.read()
+    if sabnzbd.LOGFILE and os.path.exists(sabnzbd.LOGFILE):
+        with open(sabnzbd.LOGFILE, "rb") as f:
+            log_data += f.read()
+    else:
+        log_data += b"\nFile log disabled or not found.\n\n"
 
     with open(config.get_filename(), "rb") as f:
         log_data += f.read()
@@ -682,7 +685,7 @@ def _api_showlog(name: str, kwargs: Dict[str, Union[str, List[str]]]) -> bytes:
     try:
         if cur_user := getpass.getuser():
             log_data = log_data.replace(utob(cur_user), b"<USERNAME>")
-    except:
+    except Exception:
         pass
 
     # Set headers
@@ -1270,7 +1273,7 @@ def test_nntp_server_dict(kwargs: Dict[str, Union[str, List[str]]]) -> Tuple[boo
     connections = int_conv(kwargs.get("connections", 0))
     timeout = int_conv(kwargs.get("timeout", DEF_NETWORKING_TEST_TIMEOUT))
     ssl = int_conv(kwargs.get("ssl", 0))
-    ssl_verify = int_conv(kwargs.get("ssl_verify", 1))
+    ssl_verify = int_conv(kwargs.get("ssl_verify", 3))
     ssl_ciphers = kwargs.get("ssl_ciphers", "").strip()
 
     if not host:
@@ -1311,21 +1314,45 @@ def test_nntp_server_dict(kwargs: Dict[str, Union[str, List[str]]]) -> Tuple[boo
             username=username,
             password=password,
         )
-    except:
+    except Exception:
         return False, T("Invalid server details")
 
     # All exceptions are caught internally
     test_server.request_addrinfo_blocking()
     if not test_server.addrinfo:
-        # Try if we can connect on port 80 (so web server), forcing a short timeout
-        test_server.port = 80
-        test_server.timeout = DEF_NETWORKING_TEST_TIMEOUT
-        test_server.request_addrinfo_blocking()
-        if test_server.addrinfo:
+        # so NNTP connection was tried, but did not succeed: no addrinfo. Possible causes:
+        # - user has filled out an indexer as newsserver. Not good.
+        # - user has filled out a weird port on which there is no newsserver
+        # - generic network problem (?)
+        test_server.timeout = DEF_NETWORKING_TEST_TIMEOUT  # force a short timeout
+
+        # let's try well-known ports: HTTP and NTTP(S)
+        port_working = {80: False, 119: False, 563: False}
+        for port_to_check in port_working:
+            # Don't re-check if it was already tried by user
+            if port_to_check != port:
+                test_server.port = port_to_check
+                test_server.request_addrinfo_blocking()
+                port_working[port_to_check] = bool(test_server.addrinfo)
+
+        if not port_working[119] and not port_working[563] and port_working[80]:
+            # That's a webserver, not a newsserver!
             return False, T(
                 "Could not connect to %s on port %s. It appears that %s operates as a web server (port 80), "
                 "possibly an indexer, not a usenet server. You have to fill a usenet server."
             ) % (host, port, host)
+        elif port not in (119, 563):
+            # User specified a weird port, so check if regular ones do work
+            if port_working[563]:
+                return False, T(
+                    "Could not connect to %s on port %s. Use the default usenet settings: port 563 and SSL turned on"
+                ) % (host, port)
+            if port_working[119]:
+                return False, T(
+                    "Could not connect to %s on port %s. Use the default usenet settings: port 119 and SSL turned off"
+                ) % (host, port)
+
+        # Sorry, no clever analysis:
         return False, T('Server address "%s:%s" is not valid.') % (host, port)
 
     try:
@@ -1389,7 +1416,7 @@ def build_status(calculate_performance: bool = False, skip_dashboard: bool = Fal
     # build up header full of basic information
     info = build_header(trans_functions=False)
 
-    info["logfile"] = clip_path(sabnzbd.LOGFILE)
+    info["logfile"] = clip_path(sabnzbd.LOGFILE) if sabnzbd.LOGFILE else ""
     info["weblogfile"] = clip_path(sabnzbd.WEBLOGFILE)
     info["webdir"] = clip_path(info["webdir"])
     info["loglevel"] = str(cfg.log_level())
@@ -1586,6 +1613,9 @@ def build_queue(
         else:
             slot["avg_age"] = calc_age(nzo.avg_date)
 
+        # Add timestamp when the item was added to the queue
+        slot["time_added"] = nzo.time_added
+
         slotinfo.append(slot)
         n += 1
 
@@ -1747,10 +1777,10 @@ def build_header(webdir: str = "", for_template: bool = True, trans_functions: b
         header["webdir"] = webdir or sabnzbd.WEB_DIR
         header["url_base"] = cfg.url_base()
 
-        header["windows"] = sabnzbd.WIN32
+        header["windows"] = sabnzbd.WINDOWS
         header["macos"] = sabnzbd.MACOS
 
-        header["power_options"] = sabnzbd.WIN32 or sabnzbd.MACOS or sabnzbd.LINUX_POWER
+        header["power_options"] = sabnzbd.WINDOWS or sabnzbd.MACOS or sabnzbd.LINUX_POWER
         header["pp_pause_event"] = sabnzbd.Scheduler.pp_pause_event
 
         header["apikey"] = cfg.api_key()
@@ -1774,9 +1804,9 @@ def build_header(webdir: str = "", for_template: bool = True, trans_functions: b
     header["have_warnings"] = str(sabnzbd.GUIHANDLER.count())
     header["finishaction"] = sabnzbd.QUEUECOMPLETE
 
-    header["quota"] = to_units(sabnzbd.BPSMeter.quota)
+    header["quota"] = to_units(sabnzbd.BPSMeter.quota, "B")
     header["have_quota"] = bool(sabnzbd.BPSMeter.quota > 0.0)
-    header["left_quota"] = to_units(sabnzbd.BPSMeter.left)
+    header["left_quota"] = to_units(sabnzbd.BPSMeter.left, "B")
 
     anfo = sabnzbd.ArticleCache.cache_info()
     header["cache_art"] = str(anfo.article_sum)
@@ -1828,7 +1858,7 @@ def build_history(
     try:
         history_db = sabnzbd.get_db_connection()
         close_db = False
-    except:
+    except Exception:
         # Required for repairs at startup because Cherrypy isn't active yet
         history_db = HistoryDB()
         close_db = True
@@ -1871,7 +1901,13 @@ def build_history(
 
 def add_active_history(postproc_queue: List[NzbObject], items: List[Dict[str, Any]]):
     """Get the active history queue and add it to the existing items list"""
+    nzo_ids = set([nzo["nzo_id"] for nzo in items])
+
     for nzo in postproc_queue:
+        # Skip already in history
+        if nzo.nzo_id in nzo_ids:
+            continue
+
         # This output has to be the same as fetch_history!
         item = {
             "completed": int(time.time()),
@@ -1905,6 +1941,7 @@ def add_active_history(postproc_queue: List[NzbObject], items: List[Dict[str, An
             "loaded": nzo.pp_active,
             "retry": False,
             "archive": False,
+            "time_added": nzo.time_added,
         }
         # Add stage information, in the correct order
         for stage in STAGES:
