@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -237,7 +237,7 @@ class BPSMeter:
             if abs(quota - self.quota) > 0.5:
                 self.change_quota()
             res = self.reset_quota()
-        except:
+        except Exception:
             self.defaults()
         return res
 
