@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -36,6 +36,8 @@ from sabnzbd.config import (
     OptionStr,
     OptionList,
     create_api_key,
+    get_servers,
+    save_config,
 )
 from sabnzbd.constants import (
     DEF_HOST,
@@ -71,7 +73,7 @@ class ErrorCatchingArgumentParser(argparse.ArgumentParser):
 def clean_nice_ionice_parameters(value: str) -> ValidateResult:
     """Verify that the passed parameters are not exploits"""
     if value:
-        parser = ErrorCatchingArgumentParser()
+        parser = ErrorCatchingArgumentParser(add_help=False)
 
         # Nice parameters
         parser.add_argument("-n", "--adjustment", type=int)
@@ -91,6 +93,35 @@ def clean_nice_ionice_parameters(value: str) -> ValidateResult:
     return None, value
 
 
+def supported_unrar_parameters(value: str) -> ValidateResult:
+    """Verify the user-set extra parameters are valid and supported"""
+    if value:
+        parser = ErrorCatchingArgumentParser(add_help=False)
+
+        # Large memory pages
+        parser.add_argument("-mlp", action="store_true")
+        if sabnzbd.WINDOWS:
+            # Mark of the web propagation: -om[-|1][=list]
+            parser.add_argument("-om", "-om1", "-om-", nargs="?", type=str)
+            # Priority and sleep time: -ri<p>[:<s>] (p: 0-15, s: 0-1000)
+            parser.add_argument(*("-ri" + str(p) for p in range(16)), action="store_true")
+
+        try:
+            # Make the regexp and argument parsing case-insensitive, as unrar seems to do that as well, and
+            # strip the sleep time from valid forms of -ri to avoid handling ~16k combinations of <p> and <s>
+            parser.parse_args(
+                re.sub(r"(?i)(^|\s)(-ri(?:1[0-5]|[0-9]))(?::(?:1000|[1-9][0-9]{,2}|0))?($|\s)", r"\1\2\3", value)
+                .lower()
+                .split()
+            )
+        except ValueError:
+            # Also log at start-up if invalid parameter was set in the ini
+            msg = "%s: %s" % (T("Incorrect parameter"), value)
+            logging.error(msg)
+            return msg, None
+    return None, value
+
+
 def all_lowercase(value: Union[str, List]) -> Tuple[None, Union[str, List]]:
     """Lowercase and strip everything!"""
     if isinstance(value, list):
@@ -115,9 +146,11 @@ def validate_single_tag(value: List[str]) -> Tuple[None, List[str]]:
     return None, value
 
 
-def validate_strip_right_slash(value: str) -> Tuple[None, str]:
-    """Strips the right slash"""
-    if value:
+def validate_url_base(value: str) -> Tuple[None, str]:
+    """Strips the right slash and adds starting slash, if not present"""
+    if value and isinstance(value, str):
+        if not value.startswith("/"):
+            value = "/" + value
         return None, value.rstrip("/")
     return None, value
 
@@ -152,7 +185,7 @@ def validate_host(value: str) -> ValidateResult:
         ipaddress.ip_address(value)
         # valid host, so return it
         return None, value
-    except:
+    except Exception:
         pass
 
     # we don't want a plain number. As socket.getaddrinfo("100", ...) allows that, we have to pre-check
@@ -160,7 +193,7 @@ def validate_host(value: str) -> ValidateResult:
         int(value)
         # plain int as input, which is not allowed
         return T("Invalid server address."), None
-    except:
+    except Exception:
         pass
 
     # not a plain IPv4 nor IPv6 address, so let's check if it's a name that resolves to IPv4
@@ -169,7 +202,7 @@ def validate_host(value: str) -> ValidateResult:
         # all good
         logging.debug("Valid host name")
         return None, value
-    except:
+    except Exception:
         pass
 
     # ... and if not: does it resolve to IPv6 ... ?
@@ -178,7 +211,7 @@ def validate_host(value: str) -> ValidateResult:
         # all good
         logging.debug("Valid host name")
         return None, value
-    except:
+    except Exception:
         logging.debug("No valid host name")
         pass
 
@@ -254,7 +287,7 @@ def validate_download_vs_complete_dir(root: str, value: str, default: str):
 
 def validate_scriptdir_not_appdir(root: str, value: str, default: str) -> Tuple[None, str]:
     """Warn users to not use the Program Files folder for their scripts"""
-    # Need to add seperator so /mnt/sabnzbd and /mnt/sabnzbd-data are not detected as equal
+    # Need to add separator so /mnt/sabnzbd and /mnt/sabnzbd-data are not detected as equal
     if value and same_directory(sabnzbd.DIR_PROG, os.path.join(root, value)):
         # Warn, but do not block
         sabnzbd.misc.helpful_warning(
@@ -277,6 +310,9 @@ def validate_default_if_empty(root: str, value: str, default: str) -> Tuple[None
 # Special settings
 ##############################################################################
 
+# Increase everytime we do a configuration conversion
+config_conversion_version = OptionNumber("misc", "config_conversion_version", default_val=0)
+
 # This should be here so it's initialized first when the config is read
 helpful_warnings = OptionBool("misc", "helpful_warnings", True)
 
@@ -443,7 +479,6 @@ start_paused = OptionBool("misc", "start_paused", False)
 preserve_paused_state = OptionBool("misc", "preserve_paused_state", False)
 enable_par_cleanup = OptionBool("misc", "enable_par_cleanup", True)
 process_unpacked_par2 = OptionBool("misc", "process_unpacked_par2", True)
-enable_multipar = OptionBool("misc", "enable_multipar", True)
 enable_unrar = OptionBool("misc", "enable_unrar", True)
 enable_7zip = OptionBool("misc", "enable_7zip", True)
 enable_filejoin = OptionBool("misc", "enable_filejoin", True)
@@ -486,7 +521,7 @@ wait_ext_drive = OptionNumber("misc", "wait_ext_drive", 5, minval=1, maxval=60)
 max_foldername_length = OptionNumber("misc", "max_foldername_length", DEF_FOLDER_MAX, minval=20, maxval=65000)
 marker_file = OptionStr("misc", "nomedia_marker")
 ipv6_servers = OptionBool("misc", "ipv6_servers", True)
-url_base = OptionStr("misc", "url_base", "/sabnzbd", validation=validate_strip_right_slash)
+url_base = OptionStr("misc", "url_base", "", validation=validate_url_base)
 host_whitelist = OptionList("misc", "host_whitelist", validation=all_lowercase)
 local_ranges = OptionList("misc", "local_ranges", protect=True)
 max_url_retries = OptionNumber("misc", "max_url_retries", 10, minval=1)
@@ -495,6 +530,7 @@ receive_threads = OptionNumber("misc", "receive_threads", 2, minval=1)
 switchinterval = OptionNumber("misc", "switchinterval", 0.005, minval=0.001)
 ssdp_broadcast_interval = OptionNumber("misc", "ssdp_broadcast_interval", 15, minval=1, maxval=600)
 ext_rename_ignore = OptionList("misc", "ext_rename_ignore", validation=lower_case_ext)
+unrar_parameters = OptionStr("misc", "unrar_parameters", validation=supported_unrar_parameters)
 
 
 ##############################################################################
@@ -529,7 +565,7 @@ ncenter_prio_queue_done = OptionBool("ncenter", "ncenter_prio_queue_done", False
 ncenter_prio_other = OptionBool("ncenter", "ncenter_prio_other", True)
 
 # [acenter]
-acenter_enable = OptionBool("acenter", "acenter_enable", sabnzbd.WIN32)
+acenter_enable = OptionBool("acenter", "acenter_enable", sabnzbd.WINDOWS)
 acenter_cats = OptionList("acenter", "acenter_cats", ["*"])
 acenter_prio_startup = OptionBool("acenter", "acenter_prio_startup", False)
 acenter_prio_download = OptionBool("acenter", "acenter_prio_download", False)
@@ -545,7 +581,7 @@ acenter_prio_queue_done = OptionBool("acenter", "acenter_prio_queue_done", False
 acenter_prio_other = OptionBool("acenter", "acenter_prio_other", True)
 
 # [ntfosd]
-ntfosd_enable = OptionBool("ntfosd", "ntfosd_enable", not sabnzbd.WIN32 and not sabnzbd.MACOS)
+ntfosd_enable = OptionBool("ntfosd", "ntfosd_enable", not sabnzbd.WINDOWS and not sabnzbd.MACOS)
 ntfosd_cats = OptionList("ntfosd", "ntfosd_cats", ["*"])
 ntfosd_prio_startup = OptionBool("ntfosd", "ntfosd_prio_startup", False)
 ntfosd_prio_download = OptionBool("ntfosd", "ntfosd_prio_download", False)
@@ -691,7 +727,9 @@ def set_root_folders2():
 ##############################################################################
 def new_limit():
     """Callback for article cache changes"""
-    sabnzbd.ArticleCache.new_limit(cache_limit.get_int())
+    if sabnzbd.__INITIALIZED__:
+        # Only update after full startup
+        sabnzbd.ArticleCache.new_limit(cache_limit.get_int())
 
 
 def guard_restart():
@@ -732,3 +770,78 @@ def guard_language():
 def guard_https_ver():
     """Callback for change of https verification"""
     sabnzbd.misc.set_https_verification(enable_https_verification())
+
+
+##############################################################################
+# Conversions
+##############################################################################
+
+
+def config_conversions():
+    """Update sections of the config, only once"""
+    # Basic old conversions
+    if config_conversion_version() < 1:
+        logging.info("Config conversion set 1")
+        # Convert auto-sort
+        if auto_sort() == "0":
+            auto_sort.set("")
+        elif auto_sort() == "1":
+            auto_sort.set("avg_age asc")
+
+        # Convert old series/date/movie sorters
+        if not sorters_converted():
+            sabnzbd.misc.convert_sorter_settings()
+            sorters_converted.set(True)
+
+        # Convert duplicate settings
+        if no_series_dupes():
+            no_smart_dupes.set(no_series_dupes())
+            no_series_dupes.set(0)
+
+        # Convert history retention setting
+        if history_retention():
+            sabnzbd.misc.convert_history_retention()
+            history_retention.set("")
+
+        # Add hostname to the whitelist
+        if not host_whitelist():
+            host_whitelist.set(socket.gethostname())
+
+        # Set cache limit for new users
+        if not cache_limit():
+            cache_limit.set(sabnzbd.misc.get_cache_limit())
+
+        # Done
+        config_conversion_version.set(1)
+
+    # url_base conversion
+    if config_conversion_version() < 2:
+        # We did not end up applying this conversion, so we skip this conversion_version
+        logging.info("Config conversion set 2")
+        config_conversion_version.set(2)
+
+    # Switch to par2cmdline-turbo on Windows
+    if config_conversion_version() < 3:
+        logging.info("Config conversion set 3")
+        if sabnzbd.WINDOWS and par_option():
+            # Just empty it, so we don't pass the wrong parameters
+            logging.warning(T("The par2 application was switched, any custom par2 parameters were removed"))
+            par_option.set("")
+
+        # Done
+        config_conversion_version.set(3)
+
+    # Convert Certificate Validation
+    if config_conversion_version() < 4:
+        logging.info("Config conversion set 4")
+
+        all_servers = get_servers()
+        for server in all_servers:
+            if all_servers[server].ssl_verify() == 2:
+                all_servers[server].ssl_verify.set(3)
+
+        # Done
+        config_conversion_version.set(4)
+
+    # Make sure we store the new values
+    save_config()
