@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -31,6 +31,7 @@ ANFO = namedtuple("ANFO", "article_sum cache_size cache_limit")
 # Or, when extra ".1", ".2" etc. are added for identically named jobs
 DEF_FOLDER_MAX = 256 - 10
 DEF_FILE_MAX = 255 - 10  # max filename length on modern filesystems, minus some room for extra chars later on
+DEX_FILE_EXTENSION_MAX = 20
 
 GIGI = float(2**30)
 MEBI = float(2**20)
@@ -49,7 +50,7 @@ RENAMES_FILE = "__renames__"
 ATTRIB_FILE = "SABnzbd_attrib"
 REPAIR_REQUEST = "repair-all.sab"
 
-SABCTOOLS_VERSION_REQUIRED = "8.2.5"
+SABCTOOLS_VERSION_REQUIRED = "8.2.6"
 
 DB_HISTORY_VERSION = 1
 DB_HISTORY_NAME = "history%s.db" % DB_HISTORY_VERSION
@@ -179,6 +180,7 @@ class DuplicateStatus:
 
 class AddNzbFileResult:
     RETRY = "Retry"  # File could not be read
-    ERROR = "Error"  # Rejected as duplicate, by pre-queue script or other failure to process file
+    ERROR = "Error"  # Rejected as duplicate or other failure to process file
+    PREQUEUE_REJECTED = "Pre-queue rejected"  # Rejected by pre-queue script
     OK = "OK"  # Added to queue
     NO_FILES_FOUND = "No files found"  # Malformed or might not be an NZB file
