@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -35,7 +35,7 @@ from sabnzbd.constants import DB_HISTORY_NAME, STAGES, Status, PP_LOOKUP
 from sabnzbd.bpsmeter import this_week, this_month
 from sabnzbd.decorators import synchronized
 from sabnzbd.encoding import ubtou, utob
-from sabnzbd.misc import caller_name, opts_to_pp, to_units, bool_conv
+from sabnzbd.misc import caller_name, opts_to_pp, to_units, bool_conv, match_str
 from sabnzbd.filesystem import remove_file, clip_path
 
 DB_LOCK = threading.Lock()
@@ -110,6 +110,10 @@ class HistoryDB:
                 _ = self.execute("PRAGMA user_version = 4;") and self.execute(
                     "ALTER TABLE history ADD COLUMN archive INTEGER;"
                 )
+            if version < 5:
+                _ = self.execute("PRAGMA user_version = 5;") and self.execute(
+                    "ALTER TABLE history ADD COLUMN time_added INTEGER;"
+                )
 
             HistoryDB.startup_done = True
 
@@ -119,7 +123,7 @@ class HistoryDB:
             try:
                 self.cursor.execute(command, args)
                 return True
-            except:
+            except Exception:
                 error = str(sys.exc_info()[1])
                 if tries > 0 and "is locked" in error:
                     logging.debug("Database locked, wait and retry")
@@ -129,19 +133,19 @@ class HistoryDB:
                     logging.error(T("Cannot write to History database, check access rights!"))
                     # Report back success, because there's no recovery possible
                     return True
-                elif "not a database" in error or "malformed" in error or "duplicate column name" in error:
+                elif match_str(error, ("not a database", "malformed", "no such table", "duplicate column name")):
                     logging.error(T("Damaged History database, created empty replacement"))
                     logging.info("Traceback: ", exc_info=True)
                     self.close()
                     try:
                         remove_file(HistoryDB.db_path)
-                    except:
+                    except Exception:
                         pass
                     HistoryDB.startup_done = False
                     self.connect()
                     # Return False in case of "duplicate column" error
                     # because the column addition in connect() must be terminated
-                    return "duplicate column name" not in error
+                    return True
                 else:
                     logging.error(T("SQL Command Failed, see log"))
                     logging.info("SQL: %s", command)
@@ -149,7 +153,7 @@ class HistoryDB:
                     logging.info("Traceback: ", exc_info=True)
                     try:
                         self.connection.rollback()
-                    except:
+                    except Exception:
                         # Can fail in case of automatic rollback
                         logging.debug("Rollback Failed:", exc_info=True)
             return False
@@ -187,18 +191,19 @@ class HistoryDB:
             "md5sum" TEXT,
             "password" TEXT,
             "duplicate_key" TEXT,
-            "archive" INTEGER
+            "archive" INTEGER,
+            "time_added" INTEGER
         )
         """
         )
-        self.execute("PRAGMA user_version = 4;")
+        self.execute("PRAGMA user_version = 5;")
 
     def close(self):
         """Close database connection"""
         try:
             self.cursor.close()
             self.connection.close()
-        except:
+        except Exception:
             logging.error(T("Failed to close database, see log"))
             logging.info("Traceback: ", exc_info=True)
 
@@ -293,8 +298,8 @@ class HistoryDB:
         self.execute(
             """INSERT INTO history (completed, name, nzb_name, category, pp, script, report,
             url, status, nzo_id, storage, path, script_log, script_line, download_time, postproc_time, stage_log,
-            downloaded, fail_message, url_info, bytes, duplicate_key, md5sum, password)
-            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)""",
+            downloaded, fail_message, url_info, bytes, duplicate_key, md5sum, password, time_added)
+            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)""",
             t,
         )
         logging.info("Added job %s to history", nzo.final_name)
@@ -418,7 +423,7 @@ class HistoryDB:
         if self.execute("""SELECT script_log FROM history WHERE nzo_id = ?""", (nzo_id,)):
             try:
                 data = ubtou(zlib.decompress(self.cursor.fetchone()["script_log"]))
-            except:
+            except Exception:
                 pass
         return data
 
@@ -540,6 +545,7 @@ def build_history_info(nzo, workdir_complete: str, postproc_time: int, script_ou
         nzo.duplicate_key,
         nzo.md5sum,
         nzo.correct_password,
+        nzo.time_added,
     )
 
 
@@ -556,7 +562,7 @@ def unpack_history_info(item: sqlite3.Row) -> Dict[str, Any]:
         parsed_stage_log = []
         try:
             all_stages_lines = lst.split("\r\n")
-        except:
+        except Exception:
             logging.warning(T("Invalid stage logging in history for %s"), item["name"])
             logging.debug("Lines: %s", lst)
             all_stages_lines = []
@@ -564,13 +570,13 @@ def unpack_history_info(item: sqlite3.Row) -> Dict[str, Any]:
         for stage_lines in all_stages_lines:
             try:
                 key, logs = stage_lines.split(":::")
-            except:
+            except Exception:
                 logging.info('Missing key:::logs "%s"', stage_lines)
                 continue
             stage = {"name": key, "actions": []}
             try:
                 stage["actions"] = logs.split(";")
-            except:
+            except Exception:
                 logging.warning(T("Invalid stage logging in history for %s"), item["name"])
                 logging.debug("Logs: %s", logs)
             parsed_stage_log.append(stage)
@@ -604,6 +610,5 @@ def unpack_history_info(item: sqlite3.Row) -> Dict[str, Any]:
 
 
 def scheduled_history_purge():
-    logging.info("Scheduled history purge")
     with HistoryDB() as history_db:
         history_db.auto_history_purge()
