@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -35,7 +35,7 @@ from sabnzbd.newswrapper import NewsWrapper, NNTPPermanentError
 import sabnzbd.config as config
 import sabnzbd.cfg as cfg
 from sabnzbd.misc import from_units, helpful_warning, int_conv, MultiAddQueue
-from sabnzbd.happyeyeballs import happyeyeballs, AddrInfo
+from sabnzbd.get_addrinfo import get_fastest_addrinfo, AddrInfo
 from sabnzbd.constants import SOFT_QUEUE_LIMIT
 
 
@@ -206,7 +206,7 @@ class Server:
         self.article_queue = []
 
     def request_addrinfo(self):
-        """Launch async request to resolve server address and perform Happy Eyeballs.
+        """Launch async request to resolve server address and select the fastest.
         In some situations this can be slow and result in delayed starts and timeouts on connections.
         Because of this, the results will be cached in the server object."""
         if not self.request:
@@ -214,7 +214,7 @@ class Server:
             Thread(target=self.request_addrinfo_blocking).start()
 
     def request_addrinfo_blocking(self):
-        """Blocking attempt to run getaddrinfo() and Happy Eyeballs for specified server"""
+        """Blocking attempt to run getaddrinfo() and address selection for specified server"""
         logging.debug("Retrieving server address information for %s", self)
 
         # Disable IPV6 if desired
@@ -222,7 +222,7 @@ class Server:
         if not cfg.ipv6_servers():
             family = socket.AF_INET
 
-        self.addrinfo = happyeyeballs(self.host, self.port, self.timeout, family)
+        self.addrinfo = get_fastest_addrinfo(self.host, self.port, self.timeout, family)
         if not self.addrinfo:
             self.bad_cons += self.threads
             # Notify next call to maybe_block_server
@@ -615,7 +615,7 @@ class Downloader(Thread):
                             try:
                                 logging.info("%s@%s: Initiating connection", nw.thrdnum, server.host)
                                 nw.init_connect()
-                            except:
+                            except Exception:
                                 logging.error(
                                     T("Failed to initialize %s@%s with reason: %s"),
                                     nw.thrdnum,
@@ -682,7 +682,7 @@ class Downloader(Thread):
                 process_nw_queue.put_multiple(read)
                 process_nw_queue.join()
 
-        except:
+        except Exception:
             logging.error(T("Fatal error in Downloader"), exc_info=True)
 
     def process_nw_worker(self, read_fds: Dict[int, NewsWrapper], nw_queue: MultiAddQueue):
@@ -695,7 +695,7 @@ class Downloader(Thread):
                 # The read_fds is passed by reference, so we can access its items!
                 self.process_nw(read_fds[nw_queue.get()])
                 nw_queue.task_done()
-        except:
+        except Exception:
             # We cannot break out of the Downloader from here, so just pause
             logging.error(T("Fatal error in Downloader"), exc_info=True)
             self.pause()
@@ -988,7 +988,7 @@ class Downloader(Thread):
         except socket.error as err:
             logging.info("Looks like server closed connection: %s", err)
             self.__reset_nw(nw, "Server broke off connection", warn=True)
-        except:
+        except Exception:
             logging.error(T("Suspect error in downloader"))
             logging.info("Traceback: ", exc_info=True)
             self.__reset_nw(nw, "Server broke off connection", warn=True)
