@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -34,7 +34,7 @@ import copy
 from random import randint
 from xml.sax.saxutils import escape
 from Cheetah.Template import Template
-from typing import Optional, Callable, Union, Any, Dict
+from typing import Optional, Callable, Union, Any, Dict, List
 from guessit.api import properties as guessit_properties
 
 import sabnzbd
@@ -55,7 +55,7 @@ from sabnzbd.misc import (
     get_cpu_name,
     clean_comma_separated_list,
 )
-from sabnzbd.happyeyeballs import happyeyeballs
+from sabnzbd.get_addrinfo import get_fastest_addrinfo
 from sabnzbd.filesystem import (
     real_path,
     globber,
@@ -264,6 +264,19 @@ def check_hostname():
 COOKIE_SECRET = str(randint(1000, 100000) * os.getpid())
 
 
+def remote_ip_from_xff(xff_ips: List[str]) -> str:
+    # Per MDN docs, the first non-local/non-trusted IP (rtl) is our "client"
+    # However, it's possible that all IPs are local/trusted, so we may also
+    # return the first ip in the list as it "should" be the client
+    # https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-For#selecting_an_ip_address
+    for ip in reversed(xff_ips):
+        if not is_local_addr(ip) and not is_loopback_addr(ip):
+            return ip
+    else:
+        # If no non-local/non-trusted IPs found, return the first IP in the list
+        return xff_ips[0]
+
+
 def set_login_cookie(remove=False, remember_me=False):
     """We try to set a cookie as unique as possible
     to the current user. Based on it's IP and the
@@ -271,7 +284,16 @@ def set_login_cookie(remove=False, remember_me=False):
     number, so cookies cannot be re-used
     """
     salt = randint(1, 1000)
-    cookie_str = utob(str(salt) + cherrypy.request.remote.ip + COOKIE_SECRET)
+
+    # If we are using XFF headers, get remote IP from XFF if possible
+    if cfg.verify_xff_header() and (
+        xff_ips := clean_comma_separated_list(cherrypy.request.headers.get("X-Forwarded-For"))
+    ):
+        remote_ip = remote_ip_from_xff(xff_ips)
+    else:
+        remote_ip = cherrypy.request.remote.ip
+
+    cookie_str = utob(str(salt) + remote_ip + COOKIE_SECRET)
     cherrypy.response.cookie["login_cookie"] = hashlib.sha1(cookie_str).hexdigest()
     cherrypy.response.cookie["login_cookie"]["path"] = "/"
     cherrypy.response.cookie["login_cookie"]["httponly"] = 1
@@ -288,9 +310,6 @@ def set_login_cookie(remove=False, remember_me=False):
     if remove:
         cherrypy.response.cookie["login_cookie"]["expires"] = 0
         cherrypy.response.cookie["login_salt"]["expires"] = 0
-    else:
-        # Notify about new login
-        notifier.send_notification(T("User logged in"), T("User logged in to the web interface"), "new_login")
 
 
 def check_login_cookie():
@@ -298,7 +317,15 @@ def check_login_cookie():
     if "login_cookie" not in cherrypy.request.cookie or "login_salt" not in cherrypy.request.cookie:
         return False
 
-    cookie_str = utob(str(cherrypy.request.cookie["login_salt"].value) + cherrypy.request.remote.ip + COOKIE_SECRET)
+    # If we are using XFF headers, get remote IP from XFF if possible
+    if cfg.verify_xff_header() and (
+        xff_ips := clean_comma_separated_list(cherrypy.request.headers.get("X-Forwarded-For"))
+    ):
+        remote_ip = remote_ip_from_xff(xff_ips)
+    else:
+        remote_ip = cherrypy.request.remote.ip
+
+    cookie_str = utob(str(cherrypy.request.cookie["login_salt"].value) + remote_ip + COOKIE_SECRET)
     return cherrypy.request.cookie["login_cookie"].value == hashlib.sha1(cookie_str).hexdigest()
 
 
@@ -433,7 +460,7 @@ class MainPage:
 
             info["cpumodel"] = get_cpu_name()
             info["cpusimd"] = sabnzbd.decoder.SABCTOOLS_SIMD
-            info["docker"] = "Docker" if sabnzbd.DOCKER else ""
+            info["platform"] = sabnzbd.PLATFORM
 
             # Have logout only with HTML and if inet=5, only when we are external
             info["have_logout"] = (
@@ -502,7 +529,7 @@ class Wizard:
     @secured_expose(check_configlock=True)
     def index(self, **kwargs):
         """Show the language selection page"""
-        if sabnzbd.WIN32:
+        if sabnzbd.WINDOWS:
             from sabnzbd.utils.apireg import get_install_lng
 
             cfg.language.set(get_install_lng())
@@ -584,7 +611,7 @@ def get_access_info():
 
     try:
         addresses = socket.getaddrinfo(host, None)
-    except:
+    except Exception:
         addresses = []
 
     if web_host == "0.0.0.0":
@@ -649,6 +676,8 @@ class LoginPage:
             set_login_cookie(remember_me=kwargs.get("remember_me", False))
             # Log the success
             logging.info("Successful login from %s", cherrypy.request.remote_label)
+            # Notify about new login
+            notifier.send_notification(T("User logged in"), T("User logged in to the web interface"), "new_login")
             # Redirect
             raise Raiser("/")
         elif kwargs.get("username") or kwargs.get("password"):
@@ -843,7 +872,6 @@ SPECIAL_BOOL_LIST = (
     "api_warnings",
     "helpful_warnings",
     "ampm",
-    "disable_par2cmdline",
     "enable_unrar",
     "enable_7zip",
     "enable_filejoin",
@@ -882,6 +910,7 @@ SPECIAL_VALUE_LIST = (
     "direct_unpack_threads",
     "selftest_host",
     "ssdp_broadcast_interval",
+    "unrar_parameters",
 )
 SPECIAL_LIST_LIST = (
     "rss_odd_titles",
@@ -1020,7 +1049,7 @@ class ConfigGeneral:
             if config.validate_config_backup(config_backup_data):
                 sabnzbd.RESTORE_DATA = config_backup_data
                 return sabnzbd.api.report(data={"success": True, "restart_req": True})
-        except:
+        except Exception:
             pass
         return sabnzbd.api.report(error=T("Invalid backup archive"))
 
@@ -1144,7 +1173,7 @@ def handle_server(kwargs, root=None, new_svr=False):
         kwargs["connections"] = "1"
 
     if kwargs.get("enable") == "1":
-        if not happyeyeballs(
+        if not get_fastest_addrinfo(
             host, int_conv(port), int_conv(kwargs.get("timeout"), default=DEF_NETWORKING_TEST_TIMEOUT)
         ):
             return badParameterResponse(T('Server address "%s:%s" is not valid.') % (host, port), ajax)
@@ -1522,7 +1551,7 @@ def Strip(txt):
     """Return stripped string, can handle None"""
     try:
         return txt.strip()
-    except:
+    except Exception:
         return None
 
 
@@ -1585,12 +1614,12 @@ class ConfigScheduling:
             conf["schedlines"].append(line)
             try:
                 enabled, m, h, day_numbers, action = line.split(" ", 4)
-            except:
+            except Exception:
                 continue
             action = action.strip()
             try:
                 action, value = action.split(" ", 1)
-            except:
+            except Exception:
                 value = ""
             value = value.strip()
             if value and not value.lower().strip("0123456789kmgtp%."):
@@ -1968,7 +1997,7 @@ def GetRssLog(feed):
         good.sort(key=lambda job: job["age_ms"], reverse=True)
         bad.sort(key=lambda job: job["age_ms"], reverse=True)
         done.sort(key=lambda job: job["time_downloaded_ms"], reverse=True)
-    except:
+    except Exception:
         # Let the javascript do it then..
         pass
 
