@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2008-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2008-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -37,11 +37,9 @@ from sabnzbd import nzbstuff
 from sabnzbd.encoding import utob, correct_cherrypy_encoding
 from sabnzbd.filesystem import (
     get_filename,
-    is_valid_script,
     get_ext,
     clip_path,
     remove_file,
-    remove_data,
 )
 from sabnzbd.misc import name_to_cat, cat_pp_script_sanitizer
 from sabnzbd.constants import DEFAULT_PRIORITY, VALID_ARCHIVES, AddNzbFileResult
@@ -75,7 +73,7 @@ def add_nzbfile(
         path = nzbfile
         filename = os.path.basename(path)
         keep_default = True
-        if not sabnzbd.WIN32:
+        if not sabnzbd.WINDOWS:
             # If windows client sends file to Unix server backslashes may
             # be included, so convert these
             path = path.replace("\\", "/")
@@ -177,7 +175,7 @@ def process_nzb_archive_file(
         else:
             logging.info("File %s is not a supported archive!", filename)
             return AddNzbFileResult.ERROR, []
-    except:
+    except Exception:
         logging.info(T("Cannot read %s"), path, exc_info=True)
         return AddNzbFileResult.RETRY, []
 
@@ -220,14 +218,18 @@ def process_nzb_archive_file(
                             nzo_id=nzo_id,
                             dup_check=dup_check,
                         )
-                    except (sabnzbd.nzbstuff.NzbEmpty, sabnzbd.nzbstuff.NzbRejected):
-                        # Empty or fully rejected
+                    except (
+                        sabnzbd.nzbstuff.NzbEmpty,
+                        sabnzbd.nzbstuff.NzbRejected,
+                        sabnzbd.nzbstuff.NzbPreQueueRejected,
+                    ):
+                        # Empty or fully rejected (including pre-queue rejections)
                         pass
                     except sabnzbd.nzbstuff.NzbRejectToHistory as err:
                         # Duplicate or unwanted extension directed to history
                         sabnzbd.NzbQueue.fail_to_history(err.nzo)
                         nzo_ids.append(err.nzo.nzo_id)
-                    except:
+                    except Exception:
                         # Something else is wrong, show error
                         logging.error(T("Error while adding %s, removing"), name, exc_info=True)
                     finally:
@@ -331,13 +333,16 @@ def process_single_nzb(
         # Malformed or might not be an NZB file
         result = AddNzbFileResult.NO_FILES_FOUND
     except sabnzbd.nzbstuff.NzbRejected:
-        # Rejected as duplicate or by pre-queue script
+        # Rejected as duplicate
         result = AddNzbFileResult.ERROR
+    except sabnzbd.nzbstuff.NzbPreQueueRejected:
+        # Rejected by pre-queue script - should be silently ignored for URL fetches
+        result = AddNzbFileResult.PREQUEUE_REJECTED
     except sabnzbd.nzbstuff.NzbRejectToHistory as err:
         # Duplicate or unwanted extension directed to history
         sabnzbd.NzbQueue.fail_to_history(err.nzo)
         nzo_ids.append(err.nzo.nzo_id)
-    except:
+    except Exception:
         # Something else is wrong, show error
         logging.error(T("Error while adding %s, removing"), filename, exc_info=True)
         result = AddNzbFileResult.ERROR
@@ -409,7 +414,7 @@ def nzbfile_parser(full_nzb_path: str, nzo):
                 try:
                     file_date = datetime.datetime.fromtimestamp(int(element.attrib.get("date")))
                     file_timestamp = int(element.attrib.get("date"))
-                except:
+                except Exception:
                     file_date = datetime.datetime.fromtimestamp(time_now)
                     file_timestamp = time_now
 
@@ -450,32 +455,29 @@ def nzbfile_parser(full_nzb_path: str, nzo):
                             else:
                                 raw_article_db[partnum] = (article_id, segment_size)
                                 file_bytes += segment_size
-                        except:
+                        except Exception:
                             # In case of missing attributes
                             pass
 
-                # Sort the articles by part number, compatible with Python 3.5
+                # Skip any empty files
+                if not raw_article_db:
+                    logging.info("No valid articles in %s, skipping", file_name)
+                    continue
+
+                # Get the articles, making sure to sort the articles by part number
                 raw_article_db_sorted = [raw_article_db[partnum] for partnum in sorted(raw_article_db)]
 
                 # Create NZF
-                nzf = sabnzbd.nzbstuff.NzbFile(file_date, file_name, raw_article_db_sorted, file_bytes, nzo)
-
-                # Check if we already have this exact NZF (see custom eq-checks)
-                if nzf in nzo.files:
-                    logging.info("File %s occurred twice in NZB, skipping", nzf.filename)
-                    remove_data(nzf.nzf_id, nzo.admin_path)
+                try:
+                    nzf = sabnzbd.nzbstuff.NzbFile(file_date, file_name, raw_article_db_sorted, file_bytes, nzo)
+                except sabnzbd.nzbstuff.SkippedNzbFile:
+                    # Did not meet requirements, so continue
+                    skipped_files += 1
                     continue
 
-                # Add valid NZF's
-                if file_name and nzf.valid and nzf.nzf_id:
-                    nzo.add_nzf(nzf)
-                    valid_files += 1
-                    avg_age_sum += file_timestamp
-                else:
-                    logging.info("Error importing %s, skipping", file_name)
-                    if nzf.nzf_id:
-                        remove_data(nzf.nzf_id, nzo.admin_path)
-                    skipped_files += 1
+                nzo.add_nzf(nzf)
+                valid_files += 1
+                avg_age_sum += file_timestamp
                 element.clear()
 
     # Final bookkeeping
