@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -79,7 +79,7 @@ class NzbQueue:
                         if not repair:
                             panic_queue(os.path.join(cfg.admin_dir.get_path(), QUEUE_FILE_NAME))
                             exit_sab(2)
-            except:
+            except Exception:
                 nzo_ids = []
                 logging.error(
                     T("Error loading %s, corrupt file detected"),
@@ -117,7 +117,7 @@ class NzbQueue:
                     else:
                         try:
                             remove_file(item)
-                        except:
+                        except Exception:
                             pass
 
     @NzbQueueLocker
@@ -192,7 +192,7 @@ class NzbQueue:
                     nzo = NzbObject(name, password=password, nzbname=name, reuse=repair_folder)
                     self.add(nzo)
                     nzo_ids = [nzo.nzo_id]
-                except:
+                except Exception:
                     # NzoObject can throw exceptions if duplicate or unwanted etc
                     logging.info("Skipping %s due to exception", name, exc_info=True)
                     nzo_ids = []
@@ -207,7 +207,7 @@ class NzbQueue:
         """Send back job to queue after successful pre-check"""
         try:
             nzb_path = globber_full(old_nzo.admin_path, "*.gz")[0]
-        except:
+        except Exception:
             logging.info("Failed to find NZB file after pre-check (%s)", old_nzo.nzo_id)
             return
 
@@ -426,7 +426,7 @@ class NzbQueue:
                         # Force-remove all trace and update counters
                         nzo.bytes -= nzf.bytes
                         nzo.bytes_tried -= nzf.bytes - nzf.bytes_left
-                        if nzf.is_par2 or sabnzbd.par2file.is_parfile(nzf.filename):
+                        if nzf.is_par2 or sabnzbd.par2file.has_par2_in_filename(nzf.filename):
                             nzo.bytes_par2 -= nzf.bytes
                         del nzo.files_table[nzf_id]
                         nzo.finished_files.remove(nzf)
@@ -472,7 +472,7 @@ class NzbQueue:
             # Allow an index as second parameter, easier for some skins
             i = int(item_id_2)
             item_id_2 = self.__nzo_list[i].nzo_id
-        except:
+        except Exception:
             pass
         try:
             nzo1 = self.__nzo_table[item_id_1]
@@ -494,10 +494,10 @@ class NzbQueue:
             # to determine whether to change the priority
             nzo3 = self.__nzo_table[item_id_3]
             nzo3_priority = nzo3.priority
-            # if id1 is surrounded by items of a different priority then change it's pririty to match
+            # if id1 is surrounded by items of a different priority then change its priority to match
             if nzo2_priority != nzo1_priority and nzo3_priority != nzo1_priority or nzo2_priority > nzo1_priority:
                 nzo1.priority = nzo2_priority
-        except:
+        except Exception:
             nzo1.priority = nzo2_priority
         item_id_pos1 = -1
         item_id_pos2 = -1
@@ -656,7 +656,7 @@ class NzbQueue:
             )
             return pos
 
-        except:
+        except Exception:
             return -1
 
     @NzbQueueLocker
@@ -666,7 +666,7 @@ class NzbQueue:
             for nzo_id in nzo_ids:
                 n = self.__set_priority(nzo_id, priority)
             return n
-        except:
+        except Exception:
             return -1
 
     def has_forced_jobs(self) -> bool:
@@ -728,11 +728,10 @@ class NzbQueue:
             or (articles_left and (articles_left % sabnzbd.ArticleCache.assembler_write_trigger) == 0)
         ):
             if not nzo.precheck:
-                # Only start decoding if we have a filename and type
                 # The type is only set if sabctools could decode the article
-                if nzf.filename and nzf.type:
+                if nzf.type:
                     sabnzbd.Assembler.process(nzo, nzf, file_done)
-                elif nzf.filename.lower().endswith(".par2"):
+                elif sabnzbd.par2file.has_par2_in_filename(nzf.filename):
                     # Broken par2 file, try to get another one
                     nzo.promote_par2(nzf)
 
