@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@ from typing import Dict, Optional, Tuple
 
 from sabnzbd.constants import MEBI
 from sabnzbd.encoding import correct_unknown_encoding
+from sabnzbd.filesystem import get_basename, get_ext
 
 PROBABLY_PAR2_RE = re.compile(r"(.*)\.vol(\d*)[+\-](\d*)\.par2", re.I)
 SCAN_LIMIT = 10 * MEBI
@@ -51,19 +52,22 @@ class FilePar2Info:
     has_duplicate: bool = False
 
 
-def is_parfile(filename: str) -> bool:
-    """Check quickly whether file has par2 signature
-    or if the filename has '.par2' in it
-    """
-    if os.path.exists(filename):
+def has_par2_in_filename(filename: str) -> bool:
+    """Check quickly whether filename has '.par2' in it"""
+    if ".par2" in filename.lower():
+        return True
+    return False
+
+
+def is_par2_file(filepath: str) -> bool:
+    """Check whether file has par2 signature"""
+    if os.path.exists(filepath):
         try:
-            with open(filename, "rb") as f:
+            with open(filepath, "rb") as f:
                 buf = f.read(8)
                 return buf.startswith(PAR_PKT_ID)
-        except:
+        except Exception:
             pass
-    elif ".par2" in filename.lower():
-        return True
     return False
 
 
@@ -74,14 +78,13 @@ def analyse_par2(name: str, filepath: Optional[str] = None) -> Tuple[str, int, i
     """
     name = name.strip()
     vol = block = 0
-    m = PROBABLY_PAR2_RE.search(name)
-    if m:
+    if m := PROBABLY_PAR2_RE.search(name):
         setname = m.group(1)
         vol = m.group(2)
         block = m.group(3)
     else:
         # Base-par2 file
-        setname = os.path.splitext(name)[0].strip()
+        setname = get_basename(name).strip()
         # Could not parse the filename, need deep inspection
         # We already know it's a par2 from the is_parfile
         if filepath:
@@ -95,7 +98,7 @@ def analyse_par2(name: str, filepath: Optional[str] = None) -> Tuple[str, int, i
                         if PAR_RECOVERY_ID in buf:
                             block += 1
                         buf = f.read(128)
-            except:
+            except Exception:
                 pass
     return setname, vol, block
 
@@ -219,7 +222,7 @@ def parse_par2_file(fname: str, md5of16k: Dict[bytes, str]) -> Tuple[str, Dict[s
                     )
                 par2info.filehash = crc32
 
-                # We found hash data, add it to final tabel
+                # We found hash data, add it to final table
                 table[par2info.filename] = par2info
 
                 # Check for md5of16k duplicates
@@ -231,7 +234,7 @@ def parse_par2_file(fname: str, md5of16k: Dict[bytes, str]) -> Tuple[str, Dict[s
                     duplicates16k.append(par2info.hash16k)
                     table[par2info.filename].has_duplicate = True
 
-    except Exception as e:
+    except Exception:
         logging.info("Par2 parser crashed in file %s", fname)
         logging.debug("Traceback: ", exc_info=True)
         table = {}
@@ -244,4 +247,14 @@ def parse_par2_file(fname: str, md5of16k: Dict[bytes, str]) -> Tuple[str, Dict[s
             old_name = md5of16k.pop(hash16k)
             logging.debug("Par2-16k signature of %s not unique, discarding", old_name)
 
+    # Sort table by filename
+    # This is necessary because of the rare case that a set contains duplicate files.
+    # The crc32 quick check loops over files in the set and considered if they match an NzbFile.
+    # For example in a set with the packets in the order 003, 004, 001, 002 with 002 and 003 being identical files:
+    # We would start with 003 and the first match would be 002, therefore rename 002 to 003 overwriting the also
+    # downloaded 003 file.
+    # Finally, we would process 002 and the first unverified path will be 003 so rename 003 back to 002.
+    # The end result is we would have moved a single file from 002 to 003 to 002 and end up missing 003.
+    table = {filename: table[filename] for filename in sorted(table.keys())}
+
     return set_id, table
