@@ -105,7 +105,7 @@ except ImportError:
             return self._DST
 
 
-# only needed for encryped headers
+# only needed for encrypted headers
 try:
     try:
         from cryptography.hazmat.primitives.ciphers import algorithms, modes, Cipher
@@ -411,7 +411,7 @@ def is_rarfile(xfile):
         rar_ver = _get_rar_version(xfile)
         if rar_ver:
             return "RAR%d" % rar_ver
-    except:
+    except Exception:
         pass
     return None
 
@@ -1132,7 +1132,9 @@ class CommonParser(object):
 
             # now read actual header
             return self._parse_block_header(fd)
-        except struct.error:
+        except Exception:
+            # SABnzbd-edit:
+            # Catch all errors
             self._set_error("Broken header in RAR file")
             return None
 
@@ -1214,7 +1216,7 @@ class CommonParser(object):
             tmpf.write(suffix)
             tmpf.close()
             rf.close()
-        except:
+        except Exception:
             rf.close()
             tmpf.close()
             os.unlink(tmpname)
@@ -2134,7 +2136,7 @@ class RarExtFile(RawIOBase):
 
         On uncompressed files, the seeking works by actual
         seeks so it's fast.  On compresses files its slow
-        - forward seeking happends by reading ahead,
+        - forward seeking happens by reading ahead,
         backwards by re-opening and decompressing from the start.
         """
 
@@ -2987,7 +2989,7 @@ def membuf_tempfile(memfile):
                 break
             tmpf.write(buf)
         tmpf.close()
-    except:
+    except Exception:
         tmpf.close()
         os.unlink(tmpname)
         raise
