@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -86,7 +86,7 @@ def get_rar_extension(myrarfile):
 
                 # Combine into the extension
                 org_extension = "part%03d.rar" % volumenumber
-    except:
+    except Exception:
         pass
 
     return volumenumber, org_extension
@@ -100,5 +100,5 @@ if __name__ == "__main__":
         myfile = sys.argv[1]
         print("File:", myfile)
         print("Volume and extension:", get_rar_extension(myfile))
-    except:
+    except Exception:
         print("Please specify rar file as parameter")
