@@ -1,6 +1,6 @@
 #!/usr/bin/python3 -OO
 # -*- coding: utf-8 -*-
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -27,6 +27,10 @@ import sys
 import gettext
 import subprocess
 
+# Make sure it's run as "python tools/make_mo.py"
+if not os.path.exists("po"):
+    raise RuntimeError("Make sure to run from root directory of SABnzbd")
+
 PO_DIR = "po/main"
 POE_DIR = "po/email"
 PON_DIR = "po/nsis"
